@@ -1,11 +1,11 @@
-#' Convert raw respirometry data (rMR)
+#' Convert Raw Respirometry Data (rMR)
 #'
-#' This function is a modification of the function \code{\link[rMR]{DO.unit.convert}} from the R package \pkg{rMR} allowing to convert raw respirometry data from one DO unit to another obtained in multichannel respirometry systems.
+#' This function is the modification of the function \code{\link[rMR]{DO.unit.convert}} from the R package \pkg{rMR} allowing to convert raw respirometry data from one DO unit to another obtained in multichannel respirometry systems.
 #'
 #' @usage
 #' convert.rMR(import.file, export.file,
 #'             n.chamber = c(1,2,3,4,5,6,7,8),
-#'             logger = c("AutoResp", "FishResp", "Qbox-Aqua"),
+#'             logger = c("AutoResp", "FishResp", "QboxAqua"),
 #'             DO.units.in, DO.units.out, salinity = 0,
 #'             bar.press = 101.325, bar.units.in = "kpa")
 #'
@@ -13,13 +13,13 @@
 #' @param export.file  the name of a file with results of the DO unit conversion
 #' @param n.chamber  integer: the number of chambers used in an experiment (including empty ones)
 #' @param logger  string: the name of a logger software used for intermittent-flow respirometry. Note, that both 'OxyView' and 'Pyro Oxygen Logger' used in couple with the 'AquaResp' software should be converted to the 'FishResp' format before running this function (see the functions \code{\link{presens.aquaresp}} or \code{\link{pyroscience.aquaresp}}, respectively).
-#' @param DO.units.in  string: dissolved oxygen unit in an imported file (more information can be found in documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
-#' @param DO.units.out  string: dissolved oxygen unit in an exported file (more information can be found in documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
-#' @param salinity  string: salinity is measured in ppm (more information can be found in documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
-#' @param bar.press  string: ambient barometric pressure value (more information can be found in documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
-#' @param bar.units.in  string: barometric pressure unit (more information can be found in documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
+#' @param DO.units.in  string: dissolved oxygen unit in an imported file (more information can be found in the documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
+#' @param DO.units.out  string: dissolved oxygen unit in an exported file (more information can be found in the documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
+#' @param salinity  string: salinity is measured in ppm (more information can be found in the documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
+#' @param bar.press  string: ambient barometric pressure value (more information can be found in the documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
+#' @param bar.units.in  string: barometric pressure unit (more information can be found in the documentation of the function \code{\link{DO.unit.convert}}, R package \pkg{rMR})
 #'
-#' @return the function exports a data frame with converted DO units.
+#' @return The function exports a data frame with converted DO units.
 #'
 #' @importFrom rMR DO.unit.convert
 #' @importFrom utils write.table write.csv
@@ -38,7 +38,7 @@
 
 convert.rMR <- function(import.file, export.file,
                         n.chamber = c(1,2,3,4,5,6,7,8),
-				                logger = c("AutoResp", "FishResp", "Qbox-Aqua"),
+				                logger = c("AutoResp", "FishResp", "QboxAqua"),
 				                DO.units.in, DO.units.out,
 						            salinity = 0,
                         bar.press = 101.325,
@@ -819,7 +819,7 @@ convert.rMR <- function(import.file, export.file,
     }
 
 
-    else if (logger == "Qbox-Aqua"){
+    else if (logger == "QboxAqua"){
       MR.data.body <- read.table(import.file, sep = ",", header=T,
                                  check.names=FALSE, strip.white=T)
     if (n.chamber == 1){
